define((function () { 'use strict';

	function a () {
		console.log('effect');
	}

	a();

}));
